@@ -1,15 +1,16 @@
 test_that("aread downloads files", {
-  aread("pbiecek/graphGallery/2166dfbd3a7a68a91a2f8e6df1a44111") -> ddl_ggplot
-  aread("pbiecek/graphGallery/2166d") -> ddl_ggplot_abrv
+  aoptions('repoDir', NULL, T) 
+  aread("pbiecek/graphGallery/600bda83cb840947976bd1ce3a11879d") -> ddl_ggplot
+  aread("pbiecek/graphGallery/600bda83cb") -> ddl_ggplot_abrv
   
   expect_is(ddl_ggplot, "gg")
   expect_is(ddl_ggplot, "ggplot")
-  expect_output(str(ddl_ggplot), "List of 2")
+  expect_output(str(ddl_ggplot), "List of 9")
   expect_equal(ddl_ggplot$labels$x, "Sepal.Length")
   
   expect_is(ddl_ggplot_abrv, "gg")
   expect_is(ddl_ggplot_abrv, "ggplot")
-  expect_output(str(ddl_ggplot_abrv), "List of 2")
+  expect_output(str(ddl_ggplot_abrv), "List of 9")
   expect_equal(ddl_ggplot_abrv$labels$y, "Petal.Length")
   
   
@@ -23,6 +24,7 @@ test_that("aread downloads files", {
 
 
 test_that("asearch works properly", {
+  aoptions('repoDir', NULL, T)
   models <- asearch("pbiecek/graphGallery", patterns = c("class:lm", "coefname:Sepal.Length"))
   
   expect_output(str(models), "List of 2")
@@ -39,64 +41,46 @@ test_that("asearch works properly", {
 
 
 test_that("createEmptyRepo creates repo", {
-  createEmptyRepo("tmp_archivist")
+  createLocalRepo("arepo")
   
-  expect_equal(list.files("tmp_archivist"), c("backpack.db", "gallery"))
-  expect_error(createEmptyRepo("tmp_archivist_2", force = FALSE))
-  deleteRepo("tmp_archivist", deleteRoot = TRUE)
+  expect_equal(list.files("arepo"), c("backpack.db", "gallery"))
+  expect_error(createLocalRepo("arepo2", force = FALSE))
+  deleteLocalRepo("arepo", deleteRoot = TRUE)
 })
 
 
-# test_that("ahistory and piper works ", {
-#   invisible(createEmptyRepo("tmp"))
-#   setLocalRepo("tmp")
-#   aoptions("silent", TRUE)
-#   iris %a%
-#     dplyr::filter(Sepal.Length < 6) %a%
-#     lm(Petal.Length~Species, data=.) %a%
-#     summary() -> tmp
-#   
-#   ahistory(tmp) -> a_tmp
-#   loadFromLocalRepo(a_tmp$md5hash[1], value = TRUE) -> b_tmp
-#   
-#   expect_equal(tmp$call, b_tmp$call)
-#   expect_equal(tmp$coefficients, b_tmp$coefficients)
-#   deleteRepo("tmp")
-# })
-
-
 test_that("copying from other repositories and showRepo", {
-  repo <- "new_repo"
-  invisible(createEmptyRepo(repoDir = repo))
-  copyGithubRepo( repoTo = repo, md5hashes= "2166dfbd3a7a68a91a2f8e6df1a44111", 
+  repo <- "arepo"
+  invisible(createLocalRepo(repoDir = repo))
+  copyRemoteRepo( repoTo = repo, md5hashes= "600bda83cb840947976bd1ce3a11879d", 
                   user="pbiecek", repo="graphGallery" )
   expect_is(showLocalRepo(repoDir = repo, method = "tags"), "data.frame")
-  expect_equal(dim(showLocalRepo(repoDir = repo, method = "tags")), c(6, 3))
+  expect_equal(dim(showLocalRepo(repoDir = repo, method = "tags")), c(8, 3))
   expect_equal(names(showLocalRepo(repoDir = repo, method = "tags")), c("artifact", "tag", "createdDate"))
   
-  summaryGithubRepo(user="pbiecek", repo="graphGallery") -> graphGallery
+  summaryRemoteRepo(user="pbiecek", repo="graphGallery") -> graphGallery
   expect_output(str(graphGallery), "List of 5")
-  expect_equal(graphGallery$artifactsNumber > 55, TRUE)
+  expect_equal(graphGallery$artifactsNumber > 50, TRUE)
   
 })
 
 
 test_that("saveToRepo funcion works with regular parameters", {
-  repo <- "new_repo"
-  invisible(createEmptyRepo(repoDir = repo))
+  repo <- "aepo"
+  invisible(createLocalRepo(repoDir = repo))
   pl <- plot(iris$Sepal.Length, iris$Petal.Length)
   saveToRepo(pl, repoDir = repo) -> hash
   
   expect_equal(hash %in% showLocalRepo(repoDir = repo, "tags")[, "artifact"], TRUE)
   
-  deleteRepo("new_repo", deleteRoot = TRUE)
+  deleteLocalRepo("arepo", deleteRoot = TRUE)
 })
 
 
 test_that("loadFromRepo functions works with regular parameters", {
-  pl2 <- loadFromGithubRepo("92ada1", repo="graphGallery", user="pbiecek", 
+  pl2 <- loadFromRemoteRepo("2a6e492cb", repo="graphGallery", user="pbiecek", 
                             value=TRUE)
-  expect_output(str(pl2), "List of 9")
+  expect_output(str(pl2), "List of 13")
 })
 
 
@@ -106,16 +90,16 @@ test_that("object is properly serialized", {
 })
 
 test_that("search* functions does search", {
-  expect_equal(c("d74472d5b4eee352ba17c5a6f2472c07", "4305c5b68bade4fdf2d7b4033dc19fa5") %in%
-  searchInGithubRepo(pattern="class:gg", user="pbiecek", repo="graphGallery"), c(TRUE, TRUE))
+  expect_equal(c("600bda83cb840947976bd1ce3a11879d", "70f4f83dbfef2a8afb2f495208d0a60f") %in%
+  searchInRemoteRepo(pattern="class:gg", user="pbiecek", repo="graphGallery"), c(TRUE, TRUE))
   
-  expect_equal(c("6dcb47aaff74b1b5f292b3eddc471c17", "c112c80ae9039b658149e1d66e7507e9") %in%
-  searchInGithubRepo(pattern = list( dateFrom = "2014-09-01", 
+  expect_equal(c("f9ebb370fa8fed2057be1bb11005f5fb", "6f6623ab33ae7f98bf8f5d7457c112eb") %in%
+  searchInRemoteRepo(pattern = list( dateFrom = "2014-09-01", 
                                      dateTo = "2014-09-30" ),
                      user="pbiecek", repo="graphGallery"), c(TRUE, TRUE))
   
-  expect_equal(c("2166dfbd3a7a68a91a2f8e6df1a44111", "92ada1e052d4d963e5787bfc9c4b506c") %in%
-  multiSearchInGithubRepo(pattern=c("class:gg", "labelx:Sepal.Length"),
+  expect_equal(c("600bda83cb840947976bd1ce3a11879d", "70f4f83dbfef2a8afb2f495208d0a60f") %in%
+  multiSearchInRemoteRepo(pattern=c("class:gg", "labelx:Sepal.Length"),
                           user="pbiecek", repo="graphGallery"), c(TRUE, TRUE))
 })
 
